#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: asn1-encoding
version: 0.9.3
id: asn1-encoding-0.9.3-fec344bb54bb5da4bfe7deb0a3562b73
key: asn1e_AWULG2H3g6SCee0eL9dbv9
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: vincent@snarc.org
stability: experimental
homepage: http://github.com/vincenthz/hs-asn1
synopsis: ASN1 data reader and writer in RAW, BER and DER forms
description:
    ASN1 data reader and writer in raw form with supports for high level forms of ASN1 (BER, and DER).
category: Data
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
exposed-modules:
    Data.ASN1.Error Data.ASN1.BinaryEncoding
    Data.ASN1.BinaryEncoding.Raw Data.ASN1.Encoding Data.ASN1.Stream
    Data.ASN1.Object
hidden-modules: Data.ASN1.Prim Data.ASN1.BinaryEncoding.Parse
                Data.ASN1.BinaryEncoding.Writer Data.ASN1.Internal
                Data.ASN1.Serialize Data.ASN1.Get
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/asn1-encoding-0.9.3
library-dirs: /usr/lib/ghc-7.10.3/site-local/asn1-encoding-0.9.3
data-dir: /usr/share/arm-linux-ghc-7.10.3/asn1-encoding-0.9.3
hs-libraries: HSasn1-encoding-0.9.3-AWULG2H3g6SCee0eL9dbv9
depends:
    asn1-types-0.3.2-0a9b49f98bdd53624b82b3c86ed41efa
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    hourglass-0.2.10-b11bcf654d7049575fb45d24076b832b
haddock-interfaces: /usr/share/doc/haskell-asn1-encoding/html/asn1-encoding.haddock
haddock-html: /usr/share/doc/haskell-asn1-encoding/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
